<?php
declare(strict_types=1);
session_start();

require_once 'config.php';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $username = filter_input(INPUT_POST, 'username', FILTER_SANITIZE_STRING) ?? '';
    $password = $_POST['password'] ?? '';

    try {
        $db = Database::getInstance();
        
        // التحقق من وجود المستخدم
        $stmt = $db->prepare("SELECT id, username, password FROM users WHERE username = :username");
        $stmt->execute(['username' => $username]);
        $user = $stmt->fetch();

        // التحقق من صحة بيانات الدخول
        if ($user && password_verify($password, $user['password'])) {
            // تسجيل الدخول ناجح
            $_SESSION['user'] = $user['username'];
            $_SESSION['user_id'] = $user['id'];
            $_SESSION['last_activity'] = time();
            
            // إعدادات الجلسة الأمنية
            ini_set('session.cookie_httponly', '1');
            ini_set('session.cookie_secure', '1');
            ini_set('session.cookie_samesite', 'Strict');
            
            header('Location: welcome.php');
            exit();
        } else {
            // تسجيل الدخول فاشل
            header('Location: index.php?error=اسم المستخدم أو كلمة المرور غير صحيحة');
            exit();
        }
    } catch (PDOException $e) {
        header('Location: index.php?error=حدث خطأ في النظام، يرجى المحاولة لاحقاً');
        exit();
    }
} else {
    // إذا تم الوصول إلى الصفحة مباشرة بدون POST
    header('Location: index.php');
    exit();
} 