<?php
declare(strict_types=1);
session_start();

// التحقق من تسجيل الدخول ومدة الجلسة
if (!isset($_SESSION['user']) || !isset($_SESSION['last_activity'])) {
    header('Location: index.php');
    exit();
}

// التحقق من مدة الجلسة (30 دقيقة)
$session_timeout = 30 * 60; // 30 دقيقة
if (time() - $_SESSION['last_activity'] > $session_timeout) {
    session_unset();
    session_destroy();
    header('Location: index.php?error=انتهت مدة الجلسة، يرجى تسجيل الدخول مرة أخرى');
    exit();
}

// تحديث وقت آخر نشاط
$_SESSION['last_activity'] = time();

// إعدادات الجلسة الأمنية
ini_set('session.cookie_httponly', '1');
ini_set('session.cookie_secure', '1');
ini_set('session.cookie_samesite', 'Strict');
?>
<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">
    <title>مرحباً بك</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #f4f4f4;
            margin: 0;
            padding: 0;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
        }
        .welcome-container {
            background-color: white;
            padding: 20px;
            border-radius: 5px;
            box-shadow: 0 0 10px rgba(0,0,0,0.1);
            width: 300px;
            text-align: center;
        }
        .welcome-container h2 {
            color: #333;
        }
        .logout-btn {
            display: inline-block;
            padding: 10px 20px;
            background-color: #f44336;
            color: white;
            text-decoration: none;
            border-radius: 4px;
            margin-top: 20px;
            transition: background-color 0.3s ease;
        }
        .logout-btn:hover {
            background-color: #d32f2f;
        }
        .session-info {
            font-size: 0.8em;
            color: #666;
            margin-top: 10px;
        }
    </style>
</head>
<body>
    <div class="welcome-container">
        <h2>مرحباً بك <?php echo htmlspecialchars($_SESSION['user']); ?></h2>
        <p>لقد قمت بتسجيل الدخول بنجاح!</p>
        <div class="session-info">
            آخر نشاط: <?php echo date('H:i:s', $_SESSION['last_activity']); ?>
        </div>
        <a href="logout.php" class="logout-btn">تسجيل الخروج</a>
    </div>
</body>
</html> 